<?php

namespace Drupal\Tests\commerce_vipps\Unit;

use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\commerce_payment\Entity\PaymentInterface;
use Drupal\commerce_price\Price;
use Drupal\commerce_vipps\EventSubscriber\ReturnFromVippsExpressSubscriber;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Tests\UnitTestCase;
use zaporylie\Vipps\Model\Payment\ResponseGetPaymentDetails;
use zaporylie\Vipps\Model\Payment\TransactionSummary;

/**
 * Class ReturnFromVippsExpressSubscriberTest.
 *
 * @package Drupal\Tests\commerce_vipps\Unit
 * @coversDefaultClass \Drupal\commerce_vipps\EventSubscriber\ReturnFromVippsExpressSubscriber
 * @group commerce_vipps
 */
class ReturnFromVippsExpressSubscriberTest extends UnitTestCase {

  /**
   * The return from vipps express subscriber.
   *
   * @var \Drupal\commerce_vipps\EventSubscriber\ReturnFromVippsExpressSubscriber
   */
  protected $subscriber;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    // TODO: Change the autogenerated stub.
    parent::setUp();
    $etm = $this->prophesize(EntityTypeManagerInterface::class);;
    $this->subscriber = new ReturnFromVippsExpressSubscriber(
      $etm->reveal()
    );
  }

  /**
   * Tests if the price is correctly amended.
   *
   * @dataProvider provideTestPrices
   */
  public function testGetAmendedPrice($expected, $captured, $remaining) {
    $amount = $this->getPayment(['amount' => new Price($expected, 'NOK')])->getAmount();
    $this->assertEquals($amount, $this->subscriber->getAmendedPrice($this->getDetails(['transactionSummary' => ['capturedAmount' => $captured, 'remainingAmountToCapture' => $remaining]]), $amount));
  }

  /**
   * Test data.
   *
   * @return array
   *   Array of test cases.
   */
  public function provideTestPrices() {
    return [
      'one-krone' => ['1', '100', '0'],
      'one-øre' => ['0.01', '1', '0'],
    ];
  }

  /**
   * Payment mock helper.
   *
   * @param array $values
   *   List of values for the payment object. Currently only amount is
   *   supported.
   *
   * @return \Drupal\commerce_payment\Entity\PaymentInterface
   *   The payment.
   */
  protected function getPayment(array $values = []) {
    $values += ['amount' => new Price(0, 'NOK')];
    $payment = $this->getMockBuilder(PaymentInterface::class)->getMock();
    $payment->expects($this->any())->method('getAmount')->willReturn($values['amount']);
    $payment->expects($this->any())->method('setAmount')->willReturn($this->returnSelf());
    return $payment;
  }

  /**
   * Order mock helper.
   *
   * @param array $values
   *   Currently unsupported.
   *
   * @return \Drupal\commerce_order\Entity\OrderInterface
   *   The order.
   */
  protected function getOrder(array $values = []) {
    $order = $this->prophesize(OrderInterface::class);
    return $order->reveal();
  }

  /**
   * Details helper.
   *
   * @param array $values
   *   Values that should be used for in object.
   *
   * @return \zaporylie\Vipps\Model\Payment\ResponseGetPaymentDetails
   *   Payment details response object.
   *
   * @throws \ReflectionException
   */
  protected function getDetails(array $values = []) {
    $values = array_replace_recursive(['transactionSummary' => ['capturedAmount' => 0, 'remainingAmountToCapture' => 0]], $values);
    $summary = new TransactionSummary();
    $summaryReflection = new \ReflectionObject($summary);
    $capturedAmountPropertyReflection = $summaryReflection->getProperty('capturedAmount');
    $capturedAmountPropertyReflection->setAccessible(TRUE);
    $capturedAmountPropertyReflection->setValue($summary, $values['transactionSummary']['capturedAmount']);
    $remainingAmountToCapturePropertyReflection = $summaryReflection->getProperty('remainingAmountToCapture');
    $remainingAmountToCapturePropertyReflection->setAccessible(TRUE);
    $remainingAmountToCapturePropertyReflection->setValue($summary, $values['transactionSummary']['remainingAmountToCapture']);
    $details = new ResponseGetPaymentDetails();
    $detailsReflection = new \ReflectionObject($details);
    $transactionSummaryPropertyReflection = $detailsReflection->getProperty('transactionSummary');
    $transactionSummaryPropertyReflection->setAccessible(TRUE);
    $transactionSummaryPropertyReflection->setValue($details, $summary);
    return $details;
  }

}
